@@ -7,6 +7,7 @@ const (
 
 // consts to maintain existing names of various sub-resources
 const (
+	ClusterOperatorName                 = "console"
 	OpenShiftConsoleName                = "console"
 	OpenShiftConsoleNamespace           = TargetNamespace
 	OpenShiftConsoleOperatorNamespace   = "openshift-console-operator"
@@ -19,4 +20,10 @@ const (
 	OpenShiftConsoleRouteName           = OpenShiftConsoleName
 	OAuthClientName                     = OpenShiftConsoleName
 	OpenShiftConfigManagedNamespace     = "openshift-config-managed"
+	OpenShiftConfigNamespace            = "openshift-config"
+	OpenShiftCustomLogoConfigMapName    = "custom-logo"
+	TrustedCAConfigMapName              = "trusted-ca-bundle"
+	TrustedCABundleKey                  = "ca-bundle.crt"
+	TrustedCABundleMountDir             = "/etc/pki/ca-trust/extracted/pem"
+	TrustedCABundleMountFile            = "tls-ca-bundle.pem"
 )
